@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for Arg_parser - POSIX/GNU command line argument parser.
-# Copyright (C) 2011-2015 Antonio Diaz Diaz.
+# Copyright (C) 2011-2016 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute and modify it.
@@ -24,7 +24,7 @@ fi
 
 if [ -d tmp ] ; then rm -rf tmp ; fi
 mkdir tmp
-cd "${objdir}"/tmp
+cd "${objdir}"/tmp || framework_failure
 
 in="${testdir}"/test.txt
 fail=0
